==> gatling-commons-3.1.0.1-sources.jar: io/gatling/commons/stats/assertion/AssertionModel.scala <==
/*
 * Copyright 2011-2019 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.commons.stats.assertion

import io.gatling.commons.util.NumberHelper._

trait Printable {
  def printable: String
}

// ------------------- //
// -- Assertion ADT -- //
// ------------------- //

case class Assertion(path: AssertionPath, target: Target, condition: Condition)

// -------------- //
// -- Path ADT -- //
// -------------- //

sealed abstract class AssertionPath(val printable: String) extends Printable
case object Global extends AssertionPath("Global")
case object ForAll extends AssertionPath("For all requests")
case class Details(parts: List[String]) extends AssertionPath(if (parts.isEmpty) Global.printable else parts.mkString(" / "))

// ---------------- //
// -- Metric ADT -- //
// ---------------- //

sealed abstract class TimeMetric(val printable: String) extends Printable
sealed abstract class CountMetric(val printable: String) extends Printable

case object AllRequests extends CountMetric("all events")
case object FailedRequests extends CountMetric("failed events")
case object SuccessfulRequests extends CountMetric("successful events")
case object ResponseTime extends TimeMetric("response time")

// ------------------- //
// -- Selection ADT -- //
// ------------------- //

sealed abstract class TimeSelection(val printable: String) extends Printable

case object Count extends Printable {
  override val printable: String = "count"
}
case object Percent extends Printable {
  override val printable: String = "percentage"
}
case object Min extends TimeSelection("min")
case object Max extends TimeSelection("max")
case object Mean extends TimeSelection("mean")
case object StandardDeviation extends TimeSelection("standard deviation")
case class Percentiles(value: Double) extends TimeSelection(s"${value.toRank} percentile")

// ---------------- //
// -- Target ADT -- //
// ---------------- //

sealed abstract class Target(val printable: String) extends Printable
case class CountTarget(metric: CountMetric) extends Target(s"${Count.printable} of ${metric.printable}")
case class PercentTarget(metric: CountMetric) extends Target(s"${Percent.printable} of ${metric.printable}")
case class TimeTarget(metric: TimeMetric, selection: TimeSelection) extends Target(s"${selection.printable} of ${metric.printable}")
case object MeanRequestsPerSecondTarget extends Target("mean requests per second")

// ------------------- //
// -- Condition ADT -- //
// ------------------- //
sealed abstract class Condition(val printable: String) extends Printable {
  def values: List[Double]
}
case class Lte(value: Double) extends Condition("is less than or equal to") {
  override def values: List[Double] = List(value)
}
case class Gte(value: Double) extends Condition("is greater than or equal to") {
  override def values = List(value)
}
case class Lt(value: Double) extends Condition("is less than") {
  override def values: List[Double] = List(value)
}
case class Gt(value: Double) extends Condition("is greater than") {
  override def values = List(value)
}
case class Is(value: Double) extends Condition("is") {
  override def values = List(value)
}
case class Between(lowerBound: Double, upperBound: Double, inclusive: Boolean) extends Condition("is between" + (if (inclusive) " inclusive" else "")) {
  override def values = List(lowerBound, upperBound)
}
case class In(elements: List[Double]) extends Condition("is in") {
  override def values: List[Double] = elements
}

==> gatling-commons-3.3.1-sources.jar: io/gatling/commons/stats/assertion/AssertionModel.scala <==
/*
 * Copyright 2011-2019 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.commons.stats.assertion

import io.gatling.commons.util.NumberHelper._

trait Printable {
  def printable: String
}

// ------------------- //
// -- Assertion ADT -- //
// ------------------- //

final case class Assertion(path: AssertionPath, target: Target, condition: Condition)

// -------------- //
// -- Path ADT -- //
// -------------- //

sealed abstract class AssertionPath(val printable: String) extends Printable
case object Global extends AssertionPath("Global")
case object ForAll extends AssertionPath("For all requests")
final case class Details(parts: List[String]) extends AssertionPath(if (parts.isEmpty) Global.printable else parts.mkString(" / "))

// ---------------- //
// -- Metric ADT -- //
// ---------------- //

sealed abstract class TimeMetric(val printable: String) extends Printable
sealed abstract class CountMetric(val printable: String) extends Printable

case object AllRequests extends CountMetric("all events")
case object FailedRequests extends CountMetric("failed events")
case object SuccessfulRequests extends CountMetric("successful events")
case object ResponseTime extends TimeMetric("response time")

// ------------------- //
// -- Selection ADT -- //
// ------------------- //

sealed abstract class TimeSelection(val printable: String) extends Printable

case object Count extends Printable {
  override val printable: String = "count"
}
case object Percent extends Printable {
  override val printable: String = "percentage"
}
case object Min extends TimeSelection("min")
case object Max extends TimeSelection("max")
case object Mean extends TimeSelection("mean")
case object StandardDeviation extends TimeSelection("standard deviation")
final case class Percentiles(value: Double) extends TimeSelection(s"${value.toRank} percentile")

// ---------------- //
// -- Target ADT -- //
// ---------------- //

sealed abstract class Target(val printable: String) extends Printable
final case class CountTarget(metric: CountMetric) extends Target(s"${Count.printable} of ${metric.printable}")
final case class PercentTarget(metric: CountMetric) extends Target(s"${Percent.printable} of ${metric.printable}")
final case class TimeTarget(metric: TimeMetric, selection: TimeSelection) extends Target(s"${selection.printable} of ${metric.printable}")
case object MeanRequestsPerSecondTarget extends Target("mean requests per second")

// ------------------- //
// -- Condition ADT -- //
// ------------------- //
sealed abstract class Condition(val printable: String) extends Printable {
  def values: List[Double]
}
final case class Lte(value: Double) extends Condition("is less than or equal to") {
  override def values: List[Double] = List(value)
}
final case class Gte(value: Double) extends Condition("is greater than or equal to") {
  override def values = List(value)
}
final case class Lt(value: Double) extends Condition("is less than") {
  override def values: List[Double] = List(value)
}
final case class Gt(value: Double) extends Condition("is greater than") {
  override def values = List(value)
}
final case class Is(value: Double) extends Condition("is") {
  override def values = List(value)
}
final case class Between(lowerBound: Double, upperBound: Double, inclusive: Boolean) extends Condition("is between" + (if (inclusive) " inclusive" else "")) {
  override def values = List(lowerBound, upperBound)
}
final case class In(elements: List[Double]) extends Condition("is in") {
  override def values: List[Double] = elements
}
